@@ -30,6 +30,7 @@ See also:
     The :mod:`soco.cache` module.
 """
 
+
 EVENT_ADVERTISE_IP = None
 """The IP on which to advertise to Sonos.
 
@@ -37,7 +38,7 @@ The default of None means that the relevant IP address will be detected
 automatically.
 
 See also:
-    The :mod:`soco.events` module.
+    The :mod:`soco.events_base` module.
 """
 
 EVENT_LISTENER_IP = None
@@ -47,7 +48,7 @@ The default of None means that the relevant IP address will be detected
 automatically.
 
 See also:
-    The :mod:`soco.events` module.
+    The :mod:`soco.events_base` module.
 """
 
 
@@ -57,5 +58,14 @@ EVENT_LISTENER_PORT = 1400
 The default is 1400. You must set this before subscribing to any events.
 
 See also:
-    The :mod:`soco.events` module.
+    The :mod:`soco.events_base` module.
+"""
+
+EVENTS_MODULE = None
+"""The events module to be used by the :mod:`soco.services` module.
+
+The default of None means the :mod:`soco.events` module will be used.
+
+See also:
+    The :mod:`soco.events` and :mod:`soco.events_twisted` modules.
 """
